@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2011 Guido Guenther <agx@sigxcpu.org>
+# (C) 2011 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -18,7 +18,7 @@
 Git command argument handling helpers
 """
 
-import collections
+import collections.abc
 
 
 class GitArgs(object):
@@ -58,7 +58,7 @@ class GitArgs(object):
         for arg in args:
             if isinstance(arg, str):
                 self._args.append(arg)
-            elif isinstance(arg, collections.Iterable):
+            elif isinstance(arg, collections.abc.Iterable):
                 for i in iter(arg):
                     self._args.append(str(i))
             else:
