@@ -26,12 +26,12 @@ try:
     librpm = __import__(RpmPkgPolicy.python_rpmlib_module_name)
 except ImportError:
     gbp.log.warn("Failed to import '%s' as rpm python module, using host's "
-                    "default rpm library instead" %
-                    RpmPkgPolicy.python_rpmlib_module_name)
-    import rpm as librpm
+                 "default rpm library instead" %
+                 RpmPkgPolicy.python_rpmlib_module_name)
+    import rpm as librpm  # type: ignore
 
 # Module initialization
-_rpmlog = tempfile.NamedTemporaryFile(prefix='gbp_rpmlog')
+_rpmlog = tempfile.NamedTemporaryFile(mode='w+', prefix='gbp_rpmlog')
 _rpmlogfd = _rpmlog.file
 librpm.setVerbosity(librpm.RPMLOG_INFO)
 librpm.setLogFile(_rpmlogfd)
@@ -44,4 +44,3 @@ def get_librpm_log(truncate=True):
     if truncate:
         _rpmlogfd.truncate(0)
     return log
-
