@@ -204,6 +204,7 @@ def export_patches(repo, options):
         repo.set_branch(base)
         pq_branch = current
     else:
+        base = current
         pq_branch = pq_branch_name(current)
     spec = parse_spec(options, repo)
     upstream_commit = find_upstream_commit(repo, spec, options.upstream_tag)
@@ -213,6 +214,9 @@ def export_patches(repo, options):
 
     GitCommand('status')(['--', spec.specdir])
 
+    if options.drop:
+        drop_pq(repo, base)
+
 
 def safe_patches(queue):
     """
@@ -390,6 +394,7 @@ def build_parser(name):
     parser.add_option("--force", dest="force", action="store_true",
                       default=False,
                       help="In case of import even import if the branch already exists")
+    parser.add_boolean_config_file_option("drop", dest='drop')
     parser.add_config_file_option(option_name="color", dest="color",
                                   type='tristate')
     parser.add_config_file_option(option_name="color-scheme",
