@@ -176,7 +176,7 @@ def guess_commit(section, repo, options):
     header = section.header
 
     # Try to parse the fields from the header revision
-    rev_re = '^%s$' % re.sub(r'%\((\S+?)\)s', r'(?P<\1>\S+)',
+    rev_re = '^%s$' % re.sub(r'%\((\S+?)\)s', r'(?P<\1>\\S+)',
                              options.changelog_revision)
     match = re.match(rev_re, header['revision'], re.I)
     fields = match.groupdict() if match else {}
