@@ -86,7 +86,6 @@ class TestDebianSource(testutils.DebianGitTestRepo):
         self.assertFalse(source.is_native())
 
     def test_is_releasable(self):
-        source = DebianSource('.')
         os.makedirs('debian/')
         with open('debian/changelog', 'w') as f:
             f.write("""git-buildpackage (0.2.3) unstable; urgency=low
@@ -96,11 +95,10 @@ class TestDebianSource(testutils.DebianGitTestRepo):
  -- Guido Guenther <agx@sigxcpu.org>  Mon,  2 Oct 2006 18:30:20 +0200
 """)
         source = DebianSource('.')
-        self.assertEquals(source.changelog.distribution, "unstable")
+        self.assertEqual(source.changelog.distribution, "unstable")
         self.assertTrue(source.is_releasable())
 
     def test_is_not_releasable(self):
-        source = DebianSource('.')
         os.makedirs('debian/')
         with open('debian/changelog', 'w') as f:
             f.write("""git-buildpackage (0.2.3) UNRELEASED; urgency=low
@@ -110,5 +108,36 @@ class TestDebianSource(testutils.DebianGitTestRepo):
  -- Guido Guenther <agx@sigxcpu.org>  Mon,  2 Oct 2006 18:30:20 +0200
 """)
         source = DebianSource('.')
-        self.assertEquals(source.changelog.distribution, "UNRELEASED")
+        self.assertEqual(source.changelog.distribution, "UNRELEASED")
         self.assertFalse(source.is_releasable())
+
+    def test_control(self):
+        os.makedirs('debian/')
+        with open('debian/control', 'w') as f:
+            f.write("Source: foo")
+        source = DebianSource('.')
+        self.assertIsNotNone(source.control)
+        self.assertEqual(source.control.name, "foo")
+
+    def test_cur_dir_not_toplevel(self):
+        """
+        Check if we can parse files if workdir != debian toplevel dir
+        """
+        os.makedirs('debian/')
+        with open('debian/changelog', 'w') as f:
+            f.write("""foo (0.2.3) unstable; urgency=low
+
+  * git doesn't like '~' in tag names so replace this with a dot when tagging
+
+ -- Guido Guenther <agx@sigxcpu.org>  Mon,  2 Oct 2006 18:30:20 +0200
+""")
+        with open('debian/control', 'w') as f:
+            f.write("Source: foo")
+        os.chdir('debian/')
+        source = DebianSource('..')
+        self.assertEqual(source.changelog.name, "foo")
+        self.assertEqual(source.control.name, "foo")
+
+        source = DebianSource(os.path.abspath('..'))
+        self.assertEqual(source.changelog.name, "foo")
+        self.assertEqual(source.control.name, "foo")
