@@ -62,7 +62,7 @@ class TestGbpConfigCommand(unittest.TestCase):
         printstub = self.SingleValuePrintStub()
         query = 'config.color'
         ret = gbp.scripts.config.print_cmd_values(query, printstub)
-        self.assertEqual(printstub.result, '%s=auto' % query)
+        self.assertEqual(printstub.result, 'auto')
         self.assertEqual(ret, 0)
 
     def test_print_cmd_single_value_empty_default(self):
@@ -70,7 +70,7 @@ class TestGbpConfigCommand(unittest.TestCase):
         printstub = self.SingleValuePrintStub()
         query = 'buildpackage.keyid'
         ret = gbp.scripts.config.print_cmd_values(query, printstub)
-        self.assertEqual(printstub.result, '%s=' % query)
+        self.assertEqual(printstub.result, '')
         self.assertEqual(ret, 0)
 
     def test_print_cmd_single_value_override(self):
@@ -78,7 +78,7 @@ class TestGbpConfigCommand(unittest.TestCase):
         printstub = self.SingleValuePrintStub()
         query = 'config.color-scheme'
         ret = gbp.scripts.config.print_cmd_values(query, printstub)
-        self.assertEqual(printstub.result, '%s=checkcheck' % query)
+        self.assertEqual(printstub.result, 'checkcheck')
         self.assertEqual(ret, 0)
 
     def test_print_cmd_all_values(self):
@@ -99,7 +99,7 @@ class TestGbpConfigCommand(unittest.TestCase):
             printstub = self.AllValuesPrintStub(cmd)
             ret = gbp.scripts.config.print_cmd_values(cmd, printstub)
             self.assertIn('%s.color' % cmd, printstub.result.keys())
-            self.assertEquals(printstub.result['%s.color' % cmd], 'auto')
+            self.assertEqual(printstub.result['%s.color' % cmd], 'auto')
             self.assertEqual(ret, 0)
 
     def test_nonexistent_cmds(self):
@@ -107,5 +107,5 @@ class TestGbpConfigCommand(unittest.TestCase):
         for cmd in ["import_dscs", "supercommand", "nonexistent"]:
             printstub = self.AllValuesPrintStub(cmd)
             ret = gbp.scripts.config.print_cmd_values(cmd, printstub)
-            self.assertEquals(printstub.result, dict())
+            self.assertEqual(printstub.result, dict())
             self.assertEqual(ret, 2)
